@@ -1,11 +1,11 @@
 use crate::{helpers::*, validator::generate_validators, Generator, Validator};
-use chrono::Utc;
 use gumdrop::Options;
 use serde::{Deserialize, Serialize};
 use simple_error::*;
-use std::convert::TryFrom;
+use std::convert::{TryFrom, TryInto};
 use std::str::FromStr;
-use tendermint::{block, chain, validator, AppHash, Hash};
+use tendermint::{block, chain, validator, AppHash, Hash, Time};
+use time::OffsetDateTime;
 
 #[derive(Debug, Options, Serialize, Deserialize, Clone)]
 pub struct Header {
@@ -127,10 +127,10 @@ impl Generator<block::Header> for Header {
             Err(_) => bail!("failed to construct header's chain_id"),
         };
 
-        let time = if let Some(t) = self.time {
+        let time: Time = if let Some(t) = self.time {
             get_time(t)?
         } else {
-            tendermint::Time(Utc::now())
+            OffsetDateTime::now_utc().try_into().unwrap()
         };
 
         let last_block_id = self.last_block_id_hash.map(|hash| block::Id {
