@@ -55,6 +55,9 @@ pub fn verify_signature(verifier: &public_key::Ed25519, msg: &[u8], signature: &
     sig.and_then(|sig| verifier.verify(msg, &sig)).is_ok()
 }
 
-pub fn get_time(abs: u64) -> Time {
-    (std::time::UNIX_EPOCH + std::time::Duration::from_secs(abs)).into()
+pub fn get_time(abs: u64) -> Result<Time, SimpleError> {
+    let res =
+        Time::from_unix_timestamp(abs as i64, 0).map_err(|e| SimpleError::new(e.to_string()))?;
+
+    Ok(res)
 }
